@@ -2,7 +2,7 @@ package WebService::HipChat;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.0601'; # VERSION
+our $VERSION = '0.0700'; # VERSION
 
 use Carp qw(croak);
 use MIME::Entity;
@@ -77,6 +77,13 @@ sub create_webhook {
     return $self->post("/room/$room/webhook", $data);
 }
 
+sub delete_webhook {
+    my ($self, $room, $webhook_id) = @_;
+    croak '$room is required' unless $room;
+    croak '$webhook_id is required' unless $webhook_id;
+    return $self->delete("/room/$room/webhook/$webhook_id");
+}
+
 sub get_members {
     my ($self, $room, %args) = @_;
     croak '$room is required' unless $room;
@@ -207,7 +214,7 @@ WebService::HipChat
 
 =head1 VERSION
 
-version 0.0601
+version 0.0700
 
 =head1 SYNOPSIS
 
